


#ifndef __PANEL_TYPEBUILTINS_H__
#define __PANEL_TYPEBUILTINS_H__ 1

#include <glib-object.h>

G_BEGIN_DECLS

/* --- ../gnome-panel/panel-enums.h --- */
#define PANEL_TYPE_OBJECT_TYPE panel_object_type_get_type()
GType panel_object_type_get_type (void);
#define PANEL_TYPE_ACTION_BUTTON_TYPE panel_action_button_type_get_type()
GType panel_action_button_type_get_type (void);

/* --- ../gnome-panel/panel-enums-gsettings.h --- */
#define PANEL_TYPE_OBJECT_PACK_TYPE panel_object_pack_type_get_type()
GType panel_object_pack_type_get_type (void);
#define PANEL_TYPE_ORIENTATION panel_orientation_get_type()
GType panel_orientation_get_type (void);
#define PANEL_TYPE_ANIMATION_SPEED panel_animation_speed_get_type()
GType panel_animation_speed_get_type (void);
#define PANEL_TYPE_BACKGROUND_IMAGE_STYLE panel_background_image_style_get_type()
GType panel_background_image_style_get_type (void);
#define PANEL_TYPE_THEME_VARIANT panel_theme_variant_get_type()
GType panel_theme_variant_get_type (void);

/* --- ../gnome-panel/panel-types.h --- */
#define PANEL_TYPE_SPEED panel_speed_get_type()
GType panel_speed_get_type (void);
G_END_DECLS

#endif /* __PANEL_TYPEBUILTINS_H__ */



